/***********************************************************************************
* Introduction to SQL 
* Dave Valentine
* SELECT
***********************************************************************************/

USE AdventureWorks2012;
GO

-- First Query
SELECT 'Introduction to SQL Server';

-- Give the column returned a name
SELECT ClassName = 'Introduction to SQL Server';

-- Another way to give the column returned a name
SELECT 'Introduction to SQL Server' AS ClassName;

-- Selecting date from a function
SELECT TodaysDate = GETDATE();

-- Selecting all data from the Person.Person Table
SELECT * 
FROM Person.Person;

-- Selecting only first and last name from the Person.Person Table
SELECT FirstName
	 , LastName
FROM Person.Person;

-- Selecting a distinct list of first and last names from the Person.Person Table
SELECT DISTINCT FirstName
	 , LastName
FROM Person.Person

-- Selecting First and Last Name using a where clause
SELECT FirstName
	 , LastName
FROM Person.Person
WHERE BusinessEntityID = 1;

-- Selecting First Name, Last Name, and Person Type where the Person Type is EM
SELECT FirstName
	 , LastName
	 , PersonType
FROM Person.Person
WHERE PersonType = 'EM';

-- Selecting Primary Key, First Name, and Last Name using the greater than comparison operator
SELECT BusinessEntityID
	 , FirstName
	 , LastName
FROM Person.Person
WHERE BusinessEntityID > 10000;

-- Selecting Primary Key, First Name, and Last Name using the between comparison operator
SELECT BusinessEntityID
	 , FirstName
	 , LastName
FROM Person.Person
WHERE BusinessEntityID BETWEEN 1 AND 1000;

-- Selecting Primary Key, First Name, and Last Name using a Logical AND operator
SELECT BusinessEntityID
	 , FirstName
	 , LastName
FROM Person.Person
WHERE BusinessEntityID BETWEEN 1 AND 1000 
AND PersonType = 'EM';

-- Selecting Primary Key, First Name, and Last Name using a Logical OR operator
SELECT BusinessEntityID
	 , FirstName
	 , LastName
	 , PersonType
FROM Person.Person
WHERE BusinessEntityID BETWEEN 1 AND 1000  OR PersonType = 'EM';


-- Selecting data from Person.Person using a complex where statement
-- that should return all persons that are either EM or SP that 
-- have a Primary Key > 500
SELECT BusinessEntityID
	 , FirstName
	 , LastName
	 , PersonType
FROM Person.Person
WHERE PersonType = 'EM' OR PersonType  = 'SP' AND BusinessEntityID > 500 ;


-- Selecting data from Person.Person using a complex where statement
-- that should return all persons that are either EM or SP that 
-- have a Primary Key > 500, now that we are using parenthesis the 
-- results are correct.
SELECT BusinessEntityID
	 , FirstName
	 , LastName
	 , PersonType
FROM Person.Person
WHERE (PersonType = 'EM' OR PersonType  = 'SP') AND BusinessEntityID > 500 ;


-- Selecting data from Person.Person using an IN logical operator to simplify
-- the query and return the correct resuls.
SELECT BusinessEntityID
	 , FirstName
	 , LastName
	 , PersonType
FROM Person.Person
WHERE PersonType IN ('EM','SP') AND BusinessEntityID > 500 ;


/***************************************************************************************
* END SELECT
***************************************************************************************/
