/***********************************************************************************
* Introduction to SQL 
* Dave Valentine
* String Functions Demo Scripts
***********************************************************************************/

USE AdventureWorks2012;
GO


/***********************************************************************************
* String Concatination functions
***********************************************************************************/
-- Concatinate Color and Name from the Production.Product table using the + operator
SELECT Color + Name
FROM Production.Product
WHERE ProductID IN (317,318,319,320,321,322)

-- Concatinate Color and Name from the Production.Product table using the + operator,
-- adding a space to ensure proper formatting
SELECT Color + ' ' + Name
FROM Production.Product
WHERE ProductID IN (317,318,319,320,321,322)

-- Concatinate Color and Safety Stock Level from the Production.Product table using the + operator
-- Notice the error
SELECT Name + ' ' + SafetyStockLevel
FROM Production.Product
WHERE ProductID IN (317,318,319,320,321,322)

-- Concatinate Color and Safety Stock Level from the Production.Product table using the 
-- CONCAT operator, Notice the error is gone
SELECT CONCAT(Name, ' ', SafetyStockLevel)
FROM Production.Product
WHERE ProductID IN (317,318,319,320,321,322)




/***********************************************************************************
* LEN string function
***********************************************************************************/
-- Get the string lenth for the Product Number in the Production.Product table.
SELECT Name
	 , ProductNumber
	 , ProductNumberLength = LEN(ProductNumber)
FROM Production.Product
WHERE ProductID IN (317,318,319,320,321,322)




/***********************************************************************************
* LEFT, RIGHT, and SUBSTRING string functions
***********************************************************************************/
-- Query to see the names and product numbers from the Production.Product table
SELECT Name, ProductNumber
FROM Production.Product
WHERE ProductID IN (317,318,319,320,321,322)

-- Get the Product Code (first two characters) and Product Number (last four characters) 
-- from the Product Number column in the Production.Product table.
SELECT Name	 
	 , ProductCode = LEFT(ProductNumber,2)
	 , ProductNumber = RIGHT(ProductNumber,4)
FROM Production.Product
WHERE ProductID IN (317,318,319,320,321,322)

-- Get the Product ID (first two characters after the hyphen)  from the Product Number 
-- column in the Production.Product table.
SELECT Name
	 , ProductNumber
	 , ProductID = SUBSTRING(ProductNumber,4,2)	 
FROM Production.Product
WHERE ProductID IN (317,318,319,320,321,322)

-- UPPER and LOWER String Functions
SELECT Name
	 , UpperCaseName = UPPER(Name)
	 , LowerCaseName = LOWER(Name)
FROM Production.Product
WHERE ProductID IN (317,318,319,320,321,322)



/***********************************************************************************
* LEFT, RIGHT, and SUBSTRING string functions
***********************************************************************************/
-- Query the name and ensure a space is preceeding the name
SELECT NameWithSpace = RIGHT(Name,9)
FROM Production.Product
WHERE ProductID IN (317,318,319)

-- Using the LTRIM and RTRIM functions remove the space
SELECT NameWithOutSpace = RTRIM(LTRIM(RIGHT(Name,9)))
FROM Production.Product
WHERE ProductID IN (317,318,319)


/***********************************************************************************
* Replace string function
***********************************************************************************/
-- Look at the Name field in teh Production.Product table, notice the product
-- name is mis-labled as Crankarm
SELECT Name
FROM Production.Product
WHERE ProductID IN (317,318,319)

-- Replace the Crankarm portion of the text with the proper term Crankhaft.
SELECT NewName = REPLACE(Name,'Crankarm','Crankshaft')
FROM Production.Product
WHERE ProductID IN (317,318,319)

/***********************************************************************************
* End String Functions Demo
***********************************************************************************/

