/***********************************************************************************
* Introduction to SQL 
* Dave Valentine
* Numerical Functions Demo Scripts
***********************************************************************************/

USE AdventureWorks2012;
GO

/***********************************************************************************
* Basic Numerical Functions Demo Scripts
*
* Using the Abosolute Value lets get the number of values from 0
***********************************************************************************/
SELECT AbsoluteValue = ABS(-123);
SELECT AbsoluteValue = ABS(123);

/***********************************************************************************
* Apparently Business is doing well, lets square the List prices and see how the 
* customers react...
***********************************************************************************/
SELECT TOP 10 
	  P.Name
	, SquaredListPrices = SQUARE(P.ListPrice)
	, P.Size
FROM Production.Product P 
WHERE ListPrice > 0 AND Size IS NOT NULL;

/***********************************************************************************
* Apparently Business is still doing well, lets cube the List prices and see how the 
* customers react...
***********************************************************************************/
SELECT TOP 10 
	  P.Name
	, CubedListPrices = POWER(P.ListPrice,3)
	, P.Size
FROM Production.Product P 
WHERE ListPrice > 0 AND Size IS NOT NULL;

/***********************************************************************************
* Oooppss, now the customers are upset, lets give a hefty discount using the 
* square root of the list prices.  
***********************************************************************************/
SELECT TOP 10 
	  P.Name
	, SqRootListPrices = SQRT(P.ListPrice)
	, P.Size
FROM Production.Product P 
WHERE ListPrice > 0 AND Size IS NOT NULL;

/***********************************************************************************
* Customers do not want to see the cents of the List Price, lets round the List 
* Price to the nearest whole dollar value.
***********************************************************************************/
SELECT TOP 10 
	  P.Name
	, RoundedListPrice = ROUND(P.ListPrice,0)
	, P.Size
FROM Production.Product P 
WHERE ListPrice > 0 AND Size IS NOT NULL;


/***********************************************************************************
* Aggregate Numerical Functions Demo Scripts
* 
* This query will sum all list prices in the Production.Product Table
***********************************************************************************/
SELECT TotalListPrice = SUM(P.ListPrice)	
FROM Production.Product P 
WHERE ListPrice > 0 AND Size IS NOT NULL;


/***********************************************************************************
* What we really need to see is the total price by Product, so lets add in the 
* Product Name into the query.  Notice the error...
***********************************************************************************/
SELECT Name
	 , TotalListPrice = SUM(P.ListPrice)	
FROM Production.Product P 
WHERE ListPrice > 0 AND Size IS NOT NULL;

/***********************************************************************************
* This query is using a group by clause to group all like product names, this 
* will allow us to summarize the List price by product name.
***********************************************************************************/
SELECT Name
	 , TotalListPrice = SUM(P.ListPrice)	
FROM Production.Product P 
WHERE ListPrice > 0 AND Size IS NOT NULL
GROUP BY Name;

/***********************************************************************************
* This query will return the average, min, and max list prices by product name. 
* Notice that all of the values are the same... 
***********************************************************************************/
SELECT Name
	 , AverageListPrice = AVG(P.ListPrice)	
	 , MinListPrice = MIN(P.ListPrice)	
	 , MaxListPrice = MAX(P.ListPrice)	
FROM Production.Product P 
WHERE ListPrice > 0 AND Size IS NOT NULL
GROUP BY Name;



/*****************************************************************************
This query will return multiple aggregates based on the order quanties, 
grouped by product id and product name.  This query returns more detailed 
data, becuase we are joining to a sales order table.
*****************************************************************************/
SELECT p.productid,
       p.Name,
       MinOrderQty = Min(SOD.orderqty),
       MaxOrderQty = Max(SOD.orderqty),
       SumOrderQty = SUM(SOD.orderqty),
	   NumberOrderQty = COUNT(SOD.orderqty),
       AvgOrderQty = AVG(CAST(SOD.orderqty AS FLOAT))
FROM   sales.salesorderdetail SOD
INNER JOIN production.product P ON SOD.productid = P.productid
GROUP  BY p.productid, p.Name 
ORDER  BY SumOrderQty DESC;

/***********************************************************************************
* End Date Numerical Demo
***********************************************************************************/

